#ifndef TINSEL_OPCODES_H
#define TINSEL_OPCODES_H

#include "common/stdafx.h"
#include "common/str.h"

namespace Tinsel {

struct OpcodeDesc {
	uint8 code;
	uint8 numArgs;
	Common::String description;
};

#define OP_NONE(x) { x, 0, NULL }
#define OP_MAX 0x92

struct OpcodeDesc opcode_descriptions[OP_MAX + 1] = {
	{ 0x00, 0, "end of script" },
	{ 0x01, 4, "load external reference" },
	{ 0x02, 0, "..." },
	{ 0x03, 0, "..." },
	{ 0x04, 0, "..." },
	OP_NONE(0x05),
	{ 0x06, 4, "load internal reference" },
	{ 0x07, 4, "..." },
	{ 0x08, 4, "..." },
	OP_NONE(0x09),
	OP_NONE(0x0A),
	OP_NONE(0x0B),
	OP_NONE(0x0C),
	OP_NONE(0x0D),
	OP_NONE(0x0E),
	OP_NONE(0x0F),
	OP_NONE(0x10),
	OP_NONE(0x11),
	OP_NONE(0x12),
	OP_NONE(0x13),
	{ 0x14, 0, "..." },
	{ 0x15, 0, "..." },
	{ 0x16, 0, "..." },
	{ 0x17, 0, "..." },
	{ 0x18, 0, "..." },
	{ 0x19, 0, "..." },
	{ 0x1A, 0, "..." },
	{ 0x1B, 0, "..." },
	{ 0x1C, 0, "..." },
	{ 0x1D, 0, "..." },
	{ 0x1E, 0, "..." },
	OP_NONE(0x1F),
	OP_NONE(0x20),
	OP_NONE(0x21),
	OP_NONE(0x22),
	{ 0x23, 0, "..." },
	{ 0x24, 0, "..." },
	OP_NONE(0x25),
	{ 0x26, 0, "..." },
	{ 0x27, 0, "..." },
	{ 0x28, 0, "..." },
	{ 0x29, 0, "..." },
	OP_NONE(0x2A),
	{ 0x2B, 4, "..." },
	OP_NONE(0x2C),
	OP_NONE(0x2D),
	OP_NONE(0x2E),
	OP_NONE(0x2F),
	OP_NONE(0x30),
	OP_NONE(0x31),
	OP_NONE(0x32),
	OP_NONE(0x33),
	OP_NONE(0x34),
	OP_NONE(0x35),
	OP_NONE(0x36),
	OP_NONE(0x37),
	OP_NONE(0x38),
	OP_NONE(0x39),
	OP_NONE(0x3A),
	OP_NONE(0x3B),
	OP_NONE(0x3C),
	OP_NONE(0x3D),
	OP_NONE(0x3E),
	OP_NONE(0x3F),
	OP_NONE(0x40),
	{ 0x41, 1, "..." },
	OP_NONE(0x42),
	OP_NONE(0x43),
	OP_NONE(0x44),
	OP_NONE(0x45),
	OP_NONE(0x46),
	OP_NONE(0x47),
	OP_NONE(0x48),
	OP_NONE(0x49),
	{ 0x4A, 1, "..." },
	OP_NONE(0x4B),
	{ 0x4C, 1, "..." },
	OP_NONE(0x4D),
	{ 0x4E, 1, "..." },
	OP_NONE(0x4F),
	{ 0x50, 1, "..." },
	OP_NONE(0x51),
	OP_NONE(0x52),
	OP_NONE(0x53),
	OP_NONE(0x54),
	OP_NONE(0x55),
	OP_NONE(0x56),
	OP_NONE(0x57),
	OP_NONE(0x58),
	OP_NONE(0x59),
	OP_NONE(0x5A),
	OP_NONE(0x5B),
	OP_NONE(0x5C),
	OP_NONE(0x5D),
	OP_NONE(0x5E),
	OP_NONE(0x5F),
	OP_NONE(0x60),
	OP_NONE(0x61),
	OP_NONE(0x62),
	OP_NONE(0x63),
	OP_NONE(0x64),
	OP_NONE(0x65),
	OP_NONE(0x66),
	OP_NONE(0x67),
	OP_NONE(0x68),
	OP_NONE(0x69),
	OP_NONE(0x6A),
	OP_NONE(0x6B),
	OP_NONE(0x6C),
	OP_NONE(0x6D),
	OP_NONE(0x6E),
	OP_NONE(0x6F),
	OP_NONE(0x70),
	OP_NONE(0x71),
	OP_NONE(0x72),
	OP_NONE(0x73),
	OP_NONE(0x74),
	OP_NONE(0x75),
	OP_NONE(0x76),
	OP_NONE(0x77),
	OP_NONE(0x78),
	OP_NONE(0x79),
	OP_NONE(0x7A),
	OP_NONE(0x7B),
	OP_NONE(0x7C),
	OP_NONE(0x7D),
	OP_NONE(0x7E),
	OP_NONE(0x7F),
	OP_NONE(0x80),
	{ 0x81, 2, "..." },
	OP_NONE(0x82),
	OP_NONE(0x83),
	OP_NONE(0x84),
	OP_NONE(0x85),
	OP_NONE(0x86),
	OP_NONE(0x87),
	OP_NONE(0x88),
	OP_NONE(0x89),
	{ 0x8A, 2, "..." },
	OP_NONE(0x8B),
	{ 0x8C, 2, "..." },
	OP_NONE(0x8D),
	{ 0x8E, 2, "..." },
	OP_NONE(0x8F),
	OP_NONE(0x90),
	{ 0x91, 2, "..." },
	{ 0x92, 2, "..." },
};

#undef OP_NONE

}

#endif // TINSEL_OPCODES_H
